What's new in the latest versions
=================================

The new version of NoLOAD_Jax v1.0.2 is available!
The release is from 27th of October 2021.

.. toctree::
   :maxdepth: 2

   new_features/v1.0.2


Information about the latest versions
-------------------------------------

.. toctree::
   :maxdepth: 1

   new_features/v1.0.1



